.TH IMBOOT 1
.\"
.SH NAME
imboot \- bootstrap a
.I Makefile
from an
.I Imakefile
.\"
.SH SYNOPSIS
.B imboot
[
.B \-C
.I name
] [
.BI \-D define
] [
.BI \-I dir
] [
.B \-d
] [
.B \-u
] [
.I topdir
[
.I curdir
] ]
.\"
.SH DESCRIPTION
.I imboot
generates an
.I imake
command to bootstrap a
.I Makefile
from an
.IR Imakefile .
By default,
.I imboot
looks for configuration files in the
.I config
directory under the project root directory.
The
.I \-c
(or
.IR \-C )
option may be given to tell
.I imboot
to
use a set of publicly-installed configuration files
instead of (or in addition to) any files in the project's
.I config
directory.
.PP
The
.I topdir
argument specifies the location of the project root.
The default is
``\fB.\fP''
and thus may be omitted if the current directory is the project root.
Otherwise it may be specified as an absolute pathname or as a path relative
to the current directory.
.IR curdir ,
if given, specifies the name of the current directory, relative to the project
root.
.I curdir
is usually omitted.
.\"
.SH OPTIONS
.I imboot
understands the following options:
.TP 8
.B "\-c \fIname\fP
Use the named set of configuration files instead of the
files in the project's
.I config
directory.
The files are assumed to be installed in the
.I name
directory under
.IR /usr/lib/config .
.TP 8
.B "\-C \fIname\fP
Use the named set of configuration files in addition
to the files in the project's
.I config
directory.
The files are assumed to be installed in the
.I name
directory under
.IR /usr/lib/config .
.I imboot
tells
.I imake
to look in the
.I config
directory under the project root before
.I /usr/lib/config/name
when searching for configuration files.
The intent is to support an extensible configuration file architecture such
that the installed files define a baseline configuration that individual
projects can extend or override by providing project-specific information
in files in their private
.I config
directory.
.TP 8
.BI \-D define
This option is passed directly to
.IR imake ,
which passes it to
.IR cpp .
.TP 8
.BI \-I dir
This option is passed directly to
.IR imake ,
which passes it to
.IR cpp .
It is used when you want to specify additional directories in which to look
to look for configuration files.
.TP 8
.B \-d
Force definition of UseInstalled.
This is shorthand for
.BR \-DUseInstalled ,
which is turned on automatically when you specify
.I \-c
or
.IR \-C .
.TP 8
.B \-u
Force undefinition of UseInstalled.
.\"
.SH EXAMPLES
If you're in the project root, you can bootstrap a
.I Makefile
using the WRPRC configuration files like this:
.sp .5v
.nf
	% imboot \-C WRPRC
.fi
.sp .5v
If you're in a subdirectory, say,
.IR src/prog1
(two levels down), the location of the project root is
.B ../..
and you bootstrap the
.I Makefile
with:
.sp .5v
.nf
	% imboot \-C WRPRC \fB../..\fR
.fi
.\"
.SH "WHO-TO-BLAME"
Paul DuBois, dubois@primate.wisc.edu
.\"
.SH "BUGS"
It's difficult to get
.B \-D
or
.B \-I
arguments that require quotes passed through to
.IR imake.

